==> videosdk-0.0.7.tar.gz: lib/src/features/producers/bloc/producers_bloc.dart <==
import 'dart:async';

import 'package:equatable/equatable.dart';
import '../../../videosdk_client/videosdk_client.dart';
import 'package:events2/events2.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:flutter_webrtc/flutter_webrtc.dart';

part 'producers_event.dart';
part 'producers_state.dart';

class ProducersBloc extends Bloc<ProducersEvent, ProducersState> {
  late EventEmitter eventEmitter;
  late String localParticipantId;
  late RTCVideoRenderer? renderer;

  ProducersBloc({
    required this.eventEmitter,
    required this.localParticipantId,
  }) : super(ProducersState());

  @override
  Stream<ProducersState> mapEventToState(
    ProducersEvent event,
  ) async* {
    if (event is ProducerAdd) {
      yield* _mapProducerAddToState(event);
    } else if (event is ProducerRemove) {
      yield* _mapProducerRemoveToState(event);
    } else if (event is ProducerResumed) {
      yield* _mapProducerResumeToState(event);
    } else if (event is ProducerPaused) {
      yield* _mapProducerPausedToState(event);
    }
  }

  Stream<ProducersState> _mapProducerAddToState(ProducerAdd event) async* {
    final Consumer consumer = new Consumer(
      peerId: this.localParticipantId,
      appData: event.producer.appData,
      localId: event.producer.localId,
      producerId: event.producer.id,
      id: event.producer.id,
      stream: event.producer.stream,
      rtpParameters: event.producer.rtpParameters,
      track: event.producer.track,
      closed: event.producer.closed,
      rtpReceiver: null,
    );

    switch (event.producer.source) {
      case 'mic':
        {
          this.eventEmitter.emit(
            "stream-enabled-${this.localParticipantId}",
            {
              "audio": consumer,
            },
          );

          yield ProducersState.copy(state, mic: event.producer);
          break;
        }
      case 'webcam':
        {
          this.renderer = RTCVideoRenderer();
          await renderer?.initialize();

          renderer?.srcObject = consumer.stream;

          this.eventEmitter.emit(
            "stream-enabled-${this.localParticipantId}",
            {
              "video": consumer,
              "renderer": renderer as RTCVideoRenderer,
            },
          );

          yield ProducersState.copy(state, webcam: event.producer);
          break;
        }
      case 'screen':
        {
          this.renderer = RTCVideoRenderer();
          await renderer?.initialize();

          renderer?.srcObject = consumer.stream;

          this.eventEmitter.emit(
            "stream-enabled-${this.localParticipantId}",
            {
              "share": consumer,
              "shareRenderer": renderer as RTCVideoRenderer,
            },
          );

          yield ProducersState.copy(state, screen: event.producer);
          break;
        }
      default:
        break;
    }
  }

  Stream<ProducersState> _mapProducerRemoveToState(
      ProducerRemove event) async* {
    switch (event.source) {
      case 'mic':
        {
          state.mic?.close();

          this.eventEmitter.emit(
            "stream-disabled-${this.localParticipantId}",
            {
              "audioConsumerId": state.mic?.id,
            },
          );

          yield ProducersState.removeMic(state);
          break;
        }
      case 'webcam':
        {
          state.webcam?.close();

          this.eventEmitter.emit(
            "stream-disabled-${this.localParticipantId}",
            {
              "renderer": this.renderer,
              "videoConsumerId": state.webcam?.id,
            },
          );

          yield ProducersState.removeWebcam(state);
          break;
        }
      case 'screen':
        {
          state.screen?.close();

          this.eventEmitter.emit(
            "stream-disabled-${this.localParticipantId}",
            {
              "shareRenderer": this.renderer,
              "shareConsumerId": state.webcam?.id,
            },
          );

          yield ProducersState.removeScreen(state);
          break;
        }
      default:
        break;
    }
  }

  Stream<ProducersState> _mapProducerResumeToState(
      ProducerResumed event) async* {
    switch (event.source) {
      case 'mic':
        {
          yield ProducersState.copy(state, mic: state.mic!.resumeCopy());
          break;
        }
      case 'webcam':
        {
          yield ProducersState.copy(state, webcam: state.webcam!.resumeCopy());
          break;
        }
      case 'screen':
        {
          yield ProducersState.copy(state, screen: state.screen?.resumeCopy());
          break;
        }
      default:
        break;
    }
  }

  Stream<ProducersState> _mapProducerPausedToState(
      ProducerPaused event) async* {
    switch (event.source) {
      case 'mic':
        {
          yield ProducersState.copy(state, mic: state.mic!.pauseCopy());
          break;
        }
      case 'webcam':
        {
          yield ProducersState.copy(state, webcam: state.webcam!.pauseCopy());
          break;
        }
      case 'screen':
        {
          yield ProducersState.copy(state, screen: state.screen!.pauseCopy());
          break;
        }
      default:
        break;
    }
  }
}

==> videosdk-0.0.10.tar.gz: lib/src/features/producers/bloc/producers_bloc.dart <==
import 'dart:async';

import 'package:equatable/equatable.dart';
import '../../../videosdk_client/videosdk_client.dart';
import 'package:events2/events2.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:flutter_webrtc/flutter_webrtc.dart';

part 'producers_event.dart';
part 'producers_state.dart';

class ProducersBloc extends Bloc<ProducersEvent, ProducersState> {
  late EventEmitter eventEmitter;
  late String localParticipantId;
  late RTCVideoRenderer? renderer;

  ProducersBloc({
    required this.eventEmitter,
    required this.localParticipantId,
  }) : super(ProducersState());

  @override
  Stream<ProducersState> mapEventToState(
    ProducersEvent event,
  ) async* {
    if (event is ProducerAdd) {
      yield* _mapProducerAddToState(event);
    } else if (event is ProducerRemove) {
      yield* _mapProducerRemoveToState(event);
    } else if (event is ProducerResumed) {
      yield* _mapProducerResumeToState(event);
    } else if (event is ProducerPaused) {
      yield* _mapProducerPausedToState(event);
    }
  }

  Stream<ProducersState> _mapProducerAddToState(ProducerAdd event) async* {
    final Consumer consumer = new Consumer(
      peerId: this.localParticipantId,
      appData: event.producer.appData,
      localId: event.producer.localId,
      producerId: event.producer.id,
      id: event.producer.id,
      stream: event.producer.stream,
      rtpParameters: event.producer.rtpParameters,
      track: event.producer.track,
      closed: event.producer.closed,
      rtpReceiver: null,
    );

    switch (event.producer.source) {
      case 'mic':
        {
          this.eventEmitter.emit(
            "stream-enabled-${this.localParticipantId}",
            {
              "audio": consumer,
            },
          );

          yield ProducersState.copy(state, mic: event.producer);
          break;
        }
      case 'webcam':
        {
          this.renderer = RTCVideoRenderer();
          await renderer?.initialize();

          renderer?.srcObject = consumer.stream;

          this.eventEmitter.emit(
            "stream-enabled-${this.localParticipantId}",
            {
              "video": consumer,
              "renderer": renderer as RTCVideoRenderer,
            },
          );

          yield ProducersState.copy(state, webcam: event.producer);
          break;
        }
      case 'screen':
        {
          this.renderer = RTCVideoRenderer();
          await renderer?.initialize();

          renderer?.srcObject = consumer.stream;

          this.eventEmitter.emit(
            "stream-enabled-${this.localParticipantId}",
            {
              "share": consumer,
              "shareRenderer": renderer as RTCVideoRenderer,
            },
          );

          yield ProducersState.copy(state, screen: event.producer);
          break;
        }
      default:
        break;
    }
  }

  Stream<ProducersState> _mapProducerRemoveToState(
      ProducerRemove event) async* {
    switch (event.source) {
      case 'mic':
        {
          state.mic?.close();

          this.eventEmitter.emit(
            "stream-disabled-${this.localParticipantId}",
            {
              "audioConsumerId": state.mic?.id,
            },
          );

          yield ProducersState.removeMic(state);
          break;
        }
      case 'webcam':
        {
          state.webcam?.close();

          this.eventEmitter.emit(
            "stream-disabled-${this.localParticipantId}",
            {
              "renderer": this.renderer,
              "videoConsumerId": state.webcam?.id,
            },
          );

          yield ProducersState.removeWebcam(state);
          break;
        }
      case 'screen':
        {
          state.screen?.close();

          this.eventEmitter.emit(
            "stream-disabled-${this.localParticipantId}",
            {
              "shareRenderer": this.renderer,
              "shareConsumerId": state.screen?.id,
            },
          );

          yield ProducersState.removeScreen(state);
          break;
        }
      default:
        break;
    }
  }

  Stream<ProducersState> _mapProducerResumeToState(
      ProducerResumed event) async* {
    switch (event.source) {
      case 'mic':
        {
          yield ProducersState.copy(state, mic: state.mic!.resumeCopy());
          break;
        }
      case 'webcam':
        {
          yield ProducersState.copy(state, webcam: state.webcam!.resumeCopy());
          break;
        }
      case 'screen':
        {
          yield ProducersState.copy(state, screen: state.screen?.resumeCopy());
          break;
        }
      default:
        break;
    }
  }

  Stream<ProducersState> _mapProducerPausedToState(
      ProducerPaused event) async* {
    switch (event.source) {
      case 'mic':
        {
          yield ProducersState.copy(state, mic: state.mic!.pauseCopy());
          break;
        }
      case 'webcam':
        {
          yield ProducersState.copy(state, webcam: state.webcam!.pauseCopy());
          break;
        }
      case 'screen':
        {
          yield ProducersState.copy(state, screen: state.screen!.pauseCopy());
          break;
        }
      default:
        break;
    }
  }
}
